@@ -4,6 +4,8 @@ from PyQt5.QtCore import Qt
 import sys
 import numpy as np
 import scipy as sc
+import pandas as pd
+import Path
 import copy
 import re
 
@@ -291,9 +293,33 @@ class mainFormat(qtWidget.QWidget):
         layout.addWidget(qtWidget.QLabel("Death intensity exponent, A"), row, 0)
         layout.addWidget(self._mdt_exp, row, 1)
         
+        _save_params = qtWidget.QPushButton(self)
+        _save_params.setText('Save Parameters')
+        _save_params.clicked.connect(self.saveParams)
+        row = row + 1
+        layout.addWidget(_save_params, row, 0, 1, 3)
+        
         parametersTab.setLayout(layout)
         return parametersTab
+    
+    def saveParams(self):
+        params, break_type = self.validateParams()
         
+        try:
+            if self._file_name.text() == "":
+                raise Exception()
+            if self._file_path.text() == "":
+                raise Exception()
+        except:
+            self.showDialog("Enter save localization and name", "Alert")
+            return
+            
+        dfp = pd.DataFrame(params)
+        
+        filepath = Path(self._file_path.text() + '/params'  + ".csv")  
+        filepath.parent.mkdir(parents=True, exist_ok=True)  
+        dfp.to_csv(filepath)  
+    
     def outputTabUI(self):
         outputTabUI = qtWidget.QWidget()
         layout = qtWidget.QGridLayout()        
